==> zCompositions_1.0.0.tar.gz: zCompositions/man/zCompositions-package.Rd <==
\name{zCompositions}
\alias{zCompositions}
\alias{zCompositions}
\docType{package}
\title{
Replacement of zeros and nondetects in compositional data sets
}
\description{
This package implements simple functions to explore and replace left-censored data such as rounded or count zeros and values below the limit of detection (nondetects) according to compositional data analysis principles.
}
\details{
\tabular{ll}{
Package: \tab zCompositions\cr
Type: \tab Package\cr
Version: \tab 1.0.0\cr
Date: \tab 2014-05\cr
License: \tab GPL (>= 2)\cr
}
}
\author{
Javier Palarea-Albaladejo and Josep Antoni Martin-Fernandez

Maintainer: Javier Palarea-Albaladejo <javier.palarea@bioss.ac.uk>
}
\references{
Martin-Fernandez, J.A., Barcelo-Vidal, C., Pawlowsky-Glahn, V., 2003. Dealing with zeros and missing values in compositional data sets using nonparametric imputation. Mathematical Geology 35 (3), 253-27.

Martin-Fernandez, J.A., Hron, K., Templ, T., Filzmoser, P., Palarea-Albaladejo, J., 2012. Model-based replacement of rounded zeros in compositional data: Classical and robust approaches. Computational Statistics and Data Analysis 56 (2012), 2688-2704.

Martin-Fernandez JA, Hron K, Templ M, Filzmoser P, Palarea-Albaladejo J, 2014. Bayesian-multiplicative treatment of count zeros in compositional data sets. Statistical Modelling (in press)

Palarea-Albaladejo, J., Martin-Fernandez, JA, 2013. Values below detection limit in compositional chemical data. Analytica Chimica Acta 764, 32-43.

Palarea-Albaladejo, J., Martin-Fernandez, JA, 2008. A modified EM alr-algorithm for replacing rounded zeros in compositional data sets. Computers & Geosciences 34 (8), 902-917.

Palarea-Albaladejo, J., Martin-Fernandez, JA, Gomez-Garcia, J, 2007. A parametric approach for dealing with compositional rounded zeros. Mathematical Geology 39 (7), 625-645.

Palarea-Albaladejo J, Martin-Fernandez JA, Olea, RA, 2014. A bootstrap estimation scheme for chemical compositional data with nondetects. Journal of Chemometrics (to appear).
}
\keyword{compositional data}
\seealso{
Aitchison, J., 1986. The Statistical Analysis of Compositional Data. Monographs on Statistics and Applied Probability. Chapman and Hall Ltd., London, UK (re-edited in 2003 with additional material).

Pawlowsky-Glahn, V., Buccianti, A. (Eds.), 2011. Compositional Data Analysis: Theory and Applications. John Wiley & Sons, Ltd., Chichester,UK, p. 378.
}

==> zCompositions_1.0.1.tar.gz: zCompositions/man/zCompositions-package.Rd <==
\name{zCompositions}
\alias{zCompositions}
\alias{zCompositions}
\docType{package}
\title{
Replacement of zeros and nondetects in compositional data sets
}
\description{
This package implements simple functions to explore and replace left-censored data such as rounded zeros or values below the limit of detection (nondetects) and count zeros according to compositional data analysis principles.
}
\details{
\tabular{ll}{
Package: \tab zCompositions\cr
Type: \tab Package\cr
Version: \tab 1.0.1\cr
Date: \tab 2014-06\cr
License: \tab GPL (>= 2)\cr
}
}
\author{
Javier Palarea-Albaladejo and Josep Antoni Martin-Fernandez

Maintainer: Javier Palarea-Albaladejo <javier.palarea@bioss.ac.uk>
}
\references{
Martin-Fernandez, J.A., Barcelo-Vidal, C., Pawlowsky-Glahn, V., 2003. Dealing with zeros and missing values in compositional data sets using nonparametric imputation. Mathematical Geology 35 (3), 253-27.

Martin-Fernandez, J.A., Hron, K., Templ, T., Filzmoser, P., Palarea-Albaladejo, J., 2012. Model-based replacement of rounded zeros in compositional data: Classical and robust approaches. Computational Statistics and Data Analysis 56 (2012), 2688-2704.

Martin-Fernandez JA, Hron K, Templ M, Filzmoser P, Palarea-Albaladejo J, 2014. Bayesian-multiplicative treatment of count zeros in compositional data sets. Statistical Modelling (in press)

Palarea-Albaladejo, J., Martin-Fernandez, JA, 2013. Values below detection limit in compositional chemical data. Analytica Chimica Acta 764, 32-43.

Palarea-Albaladejo, J., Martin-Fernandez, JA, 2008. A modified EM alr-algorithm for replacing rounded zeros in compositional data sets. Computers & Geosciences 34 (8), 902-917.

Palarea-Albaladejo, J., Martin-Fernandez, JA, Gomez-Garcia, J, 2007. A parametric approach for dealing with compositional rounded zeros. Mathematical Geology 39 (7), 625-645.

Palarea-Albaladejo J, Martin-Fernandez JA, Olea, RA, 2014. A bootstrap estimation scheme for chemical compositional data with nondetects. Journal of Chemometrics (to appear).
}
\keyword{compositional data}
\seealso{
Aitchison, J., 1986. The Statistical Analysis of Compositional Data. Monographs on Statistics and Applied Probability. Chapman and Hall Ltd., London, UK (re-edited in 2003 with additional material).

Pawlowsky-Glahn, V., Buccianti, A. (Eds.), 2011. Compositional Data Analysis: Theory and Applications. John Wiley & Sons, Ltd., Chichester,UK, p. 378.
}
